package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!`````"9```````!``````````%BS````
M`````````$``.``+`$``&P`:``8````$````0`````````!``$```````$``
M0```````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"0```````J`)````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````(@5````````B!4`````````
M$`````````$````%`````"``````````($`````````@0```````Q3H`````
M``#%.@`````````0`````````0````0`````8`````````!@0````````&!`
M``````"X10```````+A%`````````!`````````!````!@```)"M````````
MD+U```````"0O4```````)@$````````.!4`````````$`````````(````&
M````H*T```````"@O4```````*"]0```````4`(```````!0`@````````@`
M````````!`````0```#$`@```````,0"0```````Q`)```````!$````````
M`$0`````````!`````````!0Y71D!````%B?````````6)]```````!8GT``
M`````.0`````````Y``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``"0K0```````)"]0```````D+U```````!P`@```````'`"`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!`````!````
M1TY5```````#`````@`````````$````%`````,```!'3E4`S!9A$]%W>C3I
MV?LE)8\R\2SD7QD#````/@````(````'````P`@0`%``"`HX!T@!"0@("#X`
M``!%````20```%:DFY:FW:-KR-6R<;KCDGP*BA!7Q(D%D$-%U>S$N9Q`>O!*
M:]AQ6!PY\HL<A_F<@0````````````````````````````````````#!`0``
M$@````````````````````````#6````$@````````````````````````!=
M````$@````````````````````````"T`@``$@``````````````````````
M``"6`0``$@````````````````````````!=`0``$@``````````````````
M``````!O`@``$@````````````````````````"?`@``$@``````````````
M```````````1````(``````````````````````````J`@``$@``````````
M``````````````!4`P``$@````````````````````````"D`0``$@``````
M```````````````````O`@``$@````````````````````````!T`0``$@``
M```````````````````````X`P``$@`````````````````````````=`0``
M$@````````````````````````!^````$@`````````````````````````-
M`0``$@````````````````````````!:`@``$@``````````````````````
M``"9`@``$@````````````````````````#_````$@``````````````````
M``````#V`@``$@````````````````````````!V`@``$@``````````````
M```````````W`@``$@````````````````````````![`0``$@``````````
M``````````````#;````$@````````````````````````"+`@``$@``````
M``````````````````#-`@``$@`````````````````````````@````$@``
M``````````````````````"Z````$@````````````````````````!.````
M$@````````````````````````"I`0``$@````````````````````````"2
M`@``$@````````````````````````">````$@``````````````````````
M``#M`@``$@`````````````````````````_`0``$@``````````````````
M```````B`P``$@`````````````````````````#`P``$@``````````````
M``````````#"`@``$@`````````````````````````Q`0``$@``````````
M``````````````"P`0``$@````````````````````````!]`@``$@``````
M``````````````````#@````$@````````````````````````!)`@``$@``
M```````````````````````Q`P``$@````````````````````````"$`@``
M$@````````````````````````#F`@``$@````````````````````````!I
M````$@````````````````````````#5`@``$@``````````````````````
M``!H`0``$@````````````````````````"<`0``$@``````````````````
M``````!``@``$@`````````````````````````4`P``$@``````````````
M```````````J`P``$@````````````````````````!G`@``$@``````````
M```````````````F`0``$@`````````````````````````N````$@``````
M``````````````````"M`@``$@`````````````````````````*`P``$@``
M``````````````````````!A`@``$@````````````````````````",````
M$@````````````````````````#+````$0`8`$#"0```````!`````````!,
M`P``(0`8`&#"0```````"`````````#L````$@```+`@0```````````````
M``!Y`P``$``8`,C20`````````````````"M````$0`8`(C"0````````0``
M``````!+`P``(0`8`&#"0```````"`````````!F`P``$``7`"C"0```````
M``````````!*`P``$0`8`&#"0```````"`````````!-`0``$@```/`A0```
M``````````````!M`P``$``8`"C"0`````````````````#?`@``$0`8`(#"
M0```````"``````````]````$@`````B0```````````````````;&EB<&5R
M;"YS;RXU+C(X`%]?9VUO;E]S=&%R=%]?`%!E<FQ?<WES7W1E<FT`4&5R;%]S
M>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E
M<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R
M;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A
M9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!L:6)P=&AR96%D+G-O+C``8VQO<V4`
M;'-E96LV-`!R96%D`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`'!T:')E861?
M9V5T<W!E8VEF:6,`;&EB<F5S;VQV+G-O+C(`;&EB;G-L+G-O+C$`;&EB9&PN
M<V\N,@!L:6)M+G-O+C8`;&EB8W)Y<'0N<V\N,0!L:6)U=&EL+G-O+C$`;&EB
M8RYS;RXV`&5X:70`<W1R;F-M<`!G971P=W5I9`!C;&]S961I<@!?7W-T86-K
M7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`
M<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C
M:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?
M>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H:P!S
M=')C:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`
M<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W)E9VES=&5R
M7V%T9F]R:P!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!'3$E"0U\R+C$T`$=,
M24)#7S(N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C(N-0!'3$E"0U\R+C,N-```
M```"```````#``(````$``,````$``4``@`$``0`!``````````$``0````#
M``0`!`````0`!``$``````````(`!`````0````$``0`!`````(`!`````8`
M!``$``0````$`````@`$``,`!``$```````'``0`!```````!`````$````$
M``$`!`````$`!``````````!``4`(`(``!````!@````E)&6!@``!P!^`P``
M$````!1I:0T```8`B0,``!````!R&6D)```%`),#```0````=1II"0``!`"?
M`P``$````'09:0D```,`JP,````````!``$`A@$``!``````````=1II"0``
M`@"?`P```````/"_0```````!@````D``````````````/B_0```````!@``
M``\``````````````$#"0```````!0```#X``````````````&#"0```````
M!0```$4``````````````(#"0```````!0```$@``````````````(C"0```
M````!0```$(``````````````!C`0```````!P````$``````````````"#`
M0```````!P````(``````````````"C`0```````!P````,`````````````
M`##`0```````!P````0``````````````#C`0```````!P````4`````````
M`````$#`0```````!P````8``````````````$C`0```````!P````<`````
M`````````%#`0```````!P````@``````````````%C`0```````!P```$``
M`````````````&#`0```````!P````H``````````````&C`0```````!P``
M``L``````````````'#`0```````!P````P``````````````'C`0```````
M!P````T``````````````(#`0```````!P````X``````````````(C`0```
M````!P```!```````````````)#`0```````!P```!$``````````````)C`
M0```````!P```!(``````````````*#`0```````!P```!,`````````````
M`*C`0```````!P```!0``````````````+#`0```````!P```!4`````````
M`````+C`0```````!P```!8``````````````,#`0```````!P```!<`````
M`````````,C`0```````!P```!@``````````````-#`0```````!P```!D`
M`````````````-C`0```````!P```!H``````````````.#`0```````!P``
M`!L``````````````.C`0```````!P```!P``````````````/#`0```````
M!P```!T``````````````/C`0```````!P```$8```````````````#!0```
M````!P```$D```````````````C!0```````!P```!X``````````````!#!
M0```````!P```!\``````````````!C!0```````!P```"``````````````
M`"#!0```````!P```"$``````````````"C!0```````!P```"(`````````
M`````##!0```````!P```",``````````````#C!0```````!P```"0`````
M`````````$#!0```````!P```"4``````````````$C!0```````!P```"8`
M`````````````%#!0```````!P```"<``````````````%C!0```````!P``
M`"@``````````````&#!0```````!P```"D``````````````&C!0```````
M!P```"H``````````````'#!0```````!P```"L``````````````'C!0```
M````!P```"P``````````````(#!0```````!P```"T``````````````(C!
M0```````!P```"X``````````````)#!0```````!P```"\`````````````
M`)C!0```````!P```#```````````````*#!0```````!P```#$`````````
M`````*C!0```````!P```#(``````````````+#!0```````!P```#,`````
M`````````+C!0```````!P```#0``````````````,#!0```````!P```#4`
M`````````````,C!0```````!P```#8``````````````-#!0```````!P``
M`#<``````````````-C!0```````!P```#@``````````````.#!0```````
M!P```#D``````````````.C!0```````!P```#H``````````````/#!0```
M````!P```#L``````````````/C!0```````!P```#P```````````````#"
M0```````!P```#T`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%Y9\``$B%P'0"_]!(@\0(PP```````````/\UXI\``/\EY)\`
M``\?0`#_)>*?``!H`````.G@_____R7:GP``:`$```#IT/____\ETI\``&@"
M````Z<#_____)<J?``!H`P```.FP_____R7"GP``:`0```#IH/____\ENI\`
M`&@%````Z9#_____);*?``!H!@```.F`_____R6JGP``:`<```#I</____\E
MHI\``&@(````Z6#_____)9J?``!H"0```.E0_____R62GP``:`H```#I0/__
M__\EBI\``&@+````Z3#_____)8*?``!H#````.D@_____R5ZGP``:`T```#I
M$/____\E<I\``&@.````Z0#_____)6J?``!H#P```.GP_O___R5BGP``:!``
M``#IX/[___\E6I\``&@1````Z=#^____)5*?``!H$@```.G`_O___R5*GP``
M:!,```#IL/[___\E0I\``&@4````Z:#^____)3J?``!H%0```.F0_O___R4R
MGP``:!8```#I@/[___\E*I\``&@7````Z7#^____)2*?``!H&````.E@_O__
M_R4:GP``:!D```#I4/[___\E$I\``&@:````Z4#^____)0J?``!H&P```.DP
M_O___R4"GP``:!P```#I(/[___\E^IX``&@=````Z1#^____)?*>``!H'@``
M`.D`_O___R7JG@``:!\```#I\/W___\EXIX``&@@````Z>#]____)=J>``!H
M(0```.G0_?___R72G@``:"(```#IP/W___\ERIX``&@C````Z;#]____)<*>
M``!H)````.F@_?___R6ZG@``:"4```#ID/W___\ELIX``&@F````Z8#]____
M):J>``!H)P```.EP_?___R6BG@``:"@```#I8/W___\EFIX``&@I````Z5#]
M____)9*>``!H*@```.E`_?___R6*G@``:"L```#I,/W___\E@IX``&@L````
MZ2#]____)7J>``!H+0```.D0_?___R5RG@``:"X```#I`/W___\E:IX``&@O
M````Z?#\____)6*>``!H,````.G@_/___R5:G@``:#$```#IT/S___\E4IX`
M`&@R````Z<#\____)4J>``!H,P```.FP_/___R5"G@``:#0```#IH/S___\E
M.IX``&@U````Z9#\____)3*>``!H-@```.F`_/___R4JG@``:#<```#I</S_
M__\E(IX``&@X````Z6#\____)1J>``!H.0```.E0_/___R42G@``:#H```#I
M0/S___\E"IX``&@[````Z3#\____)0*>``!H/````.D@_/___R7ZG0``:#T`
M``#I$/S__U-(@^PPB7PD'$B-?"0<2(ET)!!(C70D$$B)5"0(2(U4)`AD2(L$
M)2@```!(B40D*#'`Z'G___^ZL"!``+\`(D``2(G6Z%<V``"`/2B>````=2_H
M.?W__TB)!5*N``!(A<`/A'L!``!(B<?HH?W__XL]NYT``.BF^___QH#1"0``
M`(L]J9T``.B4^___BSV>G0``@(@Z!````NB"^___@(@Z!````8M$)!R->`5(
M8_](P><#Z(C^__],BTPD$,<%V:T```0```!(B07*K0``28L12,=`"-1A0`!(
MQT`8UV%``$B)$$B+%26=``!(B5`0BU0D'(/Z`7XHC4K^O@$```!(@\$"#Q]`
M`$V+!/&-?@1(@\8!2&/_3(E$^/A(.?%UZ(U*!$4QP(/"`[ZP0T``2&/)2(L]
M>*T``$C'1,CX`````$B)P>@G^___B<.%P'1+2(L]6JT``.A%_?__,<!(C70D
M)+^D8$``Z(07``!(A<!T.4B+/3BM``#HL_K__^A._/__B=A(BUPD*&1(,QPE
M*````'5)2(/$,%O#2(L]#ZT``.A:^___B</KI4B+/?>L``!(A?]T!^CU,P``
MZ[2_66!``$B-="0DZ"07``!(B<=(B072K```2(7`=);KV>C^_/__OP$```#H
MQ/K__P\?0``Q[4F)T5Y(B>)(@^3P4%1)Q\"@6D``2,?!0%I``$C'QQ`D0`#_
M%<Z9``#T#Q]$``"X*,)``$@]*,)``'03N`````!(A<!T";\HPD``_^!FD,,/
M'T0``&8N#Q^$``````"^*,)``$B![BC"0`!(P?X#2(GP2,'H/T@!QDC1_G01
MN`````!(A<!T![\HPD``_^###Q]$``!F+@\?A```````@#WBFP```'4754B)
MY>A^____Q@70FP```5W##Q]$``###Q]$``!F+@\?A```````ZXYF+@\?A```
M````#Q]``$%73(U/.$%6055!5%532('LF`(``&1(BP0E*````$B)A"2(`@``
M,<!(B>),C9*`````28G0#Q\`08L!28LQ28/`$$F#P0@/R(G`2(GQ28E`\$B)
M\$C!Z2!(P>@H2,'N."4`_P``2`GP2(G.2,'A"$C!YAB!X0``_P")]D@)\$@)
MR$F)0/A-.<)UKDB-L@`"```/'X``````2(M":$@S0D!(@\((2#-""$@S0OA(
MC0P`2,'H'T@)R(/@_TB)0GA(.?)UU4R+%TB+7Q!(BW<@2(MO&$R)T$R)TDR+
M3PA(P>H;2,'@!4@)T`,$)(V4,)EY@EI(B=A(BW0D"$@QZ$PAR$B-M#69>8):
M2#'H1(TL`DR)RDR)R$C!Z`)(P>(>38GH2`G"2(G82<'H&XG12#'(3"'02#'8
M2`'P3(GN2,'F!4P)QD2-)`9,B=9,B=!(P>8>2,'H`DV)XT@)\$B+="002<'K
M&T@QPD&)P$PAZDB-M#.9>8):2#'*2`'R3(GF2,'F!4P)WD2-'!9,B>Y)P>T"
M2(M4)!A(P>8>3`GN2(V4$9EY@EI,B=E(,?!!B?9,(>!,,<!(P>D;2`'03(G:
M2,'B!4@)RDR)X4G![`)(P>$>1(TL`DB)\$B+5"0@3`GA3(GN2#'(28V4$)EY
M@EI(P>X;08G,3"'83#'P2`'03(GJ2,'B!4@)\D2-!`),B=I)P>L"2(M$)"A(
MP>(>3(G&3`G:28V$!IEY@EI(P>X;2#'108G33"'I3#'A2`'!3(G`2,'@!4@)
M\$2--`A,B>A)P>T"2(M,)#!(P>`>3(GV3`GH28V,#)EY@EI(,<)!B<5,(<),
M,=I(`<I,B?%(P>$%2,'N&T@)\4R)QDG!Z`)(P>8>1(TD$4B+5"0X3`G&3(GA
M2#'P28V4$YEY@EI(P>D;08GP3"'P3#'H2`'03(GB2,'B!4@)RDR)\4G![@)(
MP>$>1(T<`DB)\$B+5"1`3`GQ3(G>2#'(28V4%9EY@EI(P>X;08G.3"'@3#'`
M2`'03(G:2,'B!4@)\D2-+`),B>))P>P"2(M$)$A(P>(>3(GN3`GB28V$`)EY
M@EI(P>X;2#'108G43"'93#'Q2`'!3(GH2,'@!4@)\$2-!`A,B=A)P>L"2(M,
M)%!(P>`>3(G&3`G828V,#IEY@EI(P>X;2#'"08G#3"'J3#'B2`'*3(G!2,'A
M!4@)\4R)[DG![0)(P>8>1(TT$4B+5"183`GN3(GQ2#'P28V4%)EY@EI(P>D;
M08GU3"'`3#'82`'03(GR2,'B!4@)RDR)P4G!Z`)(P>$>1(TD`DB)\$B+5"1@
M3`G!3(GF2#'(28V4$YEY@EI(P>X;08G(3"'P3#'H2`'03(GB2,'B!4@)\D2-
M'`),B?)(BT0D:$C!XAY)P>X"3(G>3`GR28V$!9EY@EI(P>X;2#'108G63"'A
M3#'!2`'!3(G82,'@!4@)\$2-+`A,B>!)P>P"2(M,)'!(P>`>3(GN3`G@28V,
M")EY@EI(P>X;2#'"08G$3"':3#'R2`'*3(GI2,'A!4@)\4R)WDG!ZP)(P>8>
M1(T$$4B+5"1X3`G>3(G!2#'P28V4%IEY@EI(P>D;08GS3"'H3#'@2`'03(G"
M2,'B!4@)RDR)Z4G![0)(P>$>1(TT`DB)\$B+E"2`````3`GI3(GV2#'(28V4
M%)EY@EI(P>X;08G-3"'`3#'82`'03(GR2,'B!4@)\D2-)`),B<))P>@"2(N$
M)(@```!(P>(>3(GF3`G"28V$`YEY@EI(P>X;2#'108G03"'Q3#'I2`'!3(G@
M2,'@!4@)\$B+M"20````1(T<"$R)\$G![@)(P>`>28VT-9EY@EI-B=U,"?!)
MP>T;2#'"B<%,(>),,<)(`?),B=Y(P>8%3`GNB?9(`?),B>9)P>P"2,'F'D&)
MU4P)YDR+I"28````2#'P3"'83XV$()EY@EI-B>Q(,<A)P>P;3`'`38GH2<'@
M!4T)X$6)P$P!P$V)V$G!ZP))P>`>08G$30G828GSB?9(`[0DJ````$TQPT0Q
MVDR+G"2@````2HV,&:'KV6Y-B>-(`=%,B>))P>L;2,'B!4P)VHG22`'13(GJ
M2<'M`DC!XAY!B<M,">I-B<5%B<!,`X0DL````$DQU40QZ$V)W4B-M`:AZ]EN
M3(G82<'M&TC!X`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1$
M,>%-B>Q(`Y0DN````$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!
MZP)(P>$>18G$3`G928GSB?9(`[0DP````$DQRT0QV$V)XTB-E`*AZ]EN3(G@
M2<'K&TC!X`5,"=B)P$@!PDR)Z$G![0)(P>`>08G33`GH28G-B<E(`XPDR```
M`$DQQ44QZ$V)W4Z-A`:AZ]EN3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))
MP>`>08GU30G@28G$B<!-,<1$,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`.$
M)-````!,">*)TD@!T4R)VDG!ZP)(P>(>08G,3`G:38G#18G`3`.$)-@```!)
M,=-$,=Y-B>-(C;0PH>O9;DR)X$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F
M'D&)PTP)[DF)U8G22`.4).````!),?5$,>E-B=U-C80(H>O9;DR)V4G![1M(
MP>$%3`GIB<E)`<A,B>%)P>P"2,'A'D6)Q4P)X4F)](GV23',1#'@38GL2(V4
M`J'KV6Y,B>A)P>P;2,'@!4P)X(G`2`'"3(G82<'K`D@#M"3H````2,'@'D&)
MU$P)V$F)RXG)2`.,)/````!),<-%,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%
M3`G>B?9,`<9-B>A)P>T"2<'@'D&)\TT)Z$F)Q8G`2`.$)/@```!-,<5$,>I-
MB=U(C8P1H>O9;DR)VDG![1M(P>(%3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)
MXDV)Q$6)P$DQU$0QYDV)[$B-M#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)
MWDC!YAY)P>L"08G$3`.$)``!``!,"=Y)B=.)TD@#E"0(`0``23'S1#'938GC
M38V$"*'KV6Y,B>%)P>L;2,'A!4P)V8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)
MB?6)]D@#M"00`0``23'-1#'H38G=2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`
M2`'"3(G@2<'L`DC!X!Y!B=5,">!)B<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN
M2<'L&TC!Y@5,">:)]DP!QDV)V$G!ZP))P>`>08GT30G828G#2`.,)!@!``")
MP$TQPT@#A"0@`0``1#':38GC2(V,$:'KV6Y,B>))P>L;2,'B!4P)VHG22`'1
M3(GJ2<'M`DC!XAY!B<M,">I-B<5%B<!,`X0D*`$``$DQU40Q[DV)W4B-M#"A
MZ]EN3(G82<'M&TC!X`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)(
M`Y0D,`$``$DQ]$0QX4V)[$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)
MV4G!ZP)(P>$>18G$3`G928GSB?9),<M$,=A-B>-(`[0D.`$``$B-E`*AZ]EN
M3(G@2<'K&TC!X`5,"=A$C1P03(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H
M38G=3HV$!J'KV6Y,B=Y)P>T;2,'F!4P)[DR+K"1``0``1HTT!DV)X$G![`))
MP>`>30G@3`G`1(G&28G$2(G02"'P32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,
MB?%)P>T;2,'A!4P)Z4F)]4$!S$R)V4G!ZP)(P>$>3`G908G+20G(32'P32'=
M30GH3(NL)$@!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))
MP>X"2,'B'DP)\DV)WD&)T$@)T4TAQDPAX4P)\4R+M"10`0``20'&3`'V38GN
M2`'Q3(GN2<'N&TC!Y@5,"?9$C30.3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDA
MS$PAZDP)XDR+I"18`0``20'$30'C38GT3`':38GS2<'C!4G![!M-">-%C203
M38GK2<'M`DG!XQY-">M)B<U$B=I,"=Y)(=5,(?9,">Y,BZPD8`$``$D!Q4T!
MZ$V)Y4P!QDV)X$G![1M)P>`%30GH18TL,$V)\$G![@))P>`>30GP28G61(G&
M30G#22'V32'C30GS3(NT)&@!``!)`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)
M\4:--!E,B>%)P>P"2,'A'DP)X4F)]$&)RTD)R$TAZ$TAW$T)X$R+I"1P`0``
M20'$3`'B38GT20'03(GR2<'L&TC!X@5,">)&C20"3(GJ2<'M`DC!XAY,">I-
MB=U!B=!("=%-(<5,(?%,">E,BZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(
MP>8%3`GN1(TL#DR)]DG![@)(P>8>3`GV38G&B?%("?))(<Y,(>),"?),B[0D
M@`$``$D!QDT!\TV)[DP!VDV)ZTG!XP5)P>X;30GS18TT$TV)XTG![`))P>,>
M30GC28G,1(G:3`G>22'43"'N3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)
MP>P;2<'@!4T)X$6-)#!-B>A)P>T"2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)
MZTR+K"20`0``20'%3`'I38GE20'+3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N
M`DC!X1Y,"?%)B?9)"<A!B<M-(=Y-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!
MT$R)ZDG![AM(P>(%3`GR1HTT`DR)XDG![`)(P>(>3`GB38G<08G02`G132'$
M3"'I3`GA3(ND)*`!``!)`<1,`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,
MB>Y)P>T"2,'F'DP)[DV)Q8GQ2`GR22'-3"'R3`GJ3(NL)*@!``!)`<5-`>M-
MB>5,`=I-B>-)P>T;2<'C!4T)ZT6-+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)
MWDDAUDPAYDP)]DR+M"2P`0``20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!%
MC30P38G@2<'L`DG!X!Y-">!)B=1$B<9-"<-)(?1-(>M-">-,BZ0DN`$``$D!
MQ$P!X4V)]$D!RTR)\4G![!M(P>$%3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU
M08G+20G(32'P32'=30GH3(NL),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B
M!4P)ZD:-+`),B?))P>X"38G82,'B'DP)\D&)UD@)T4TA\$PAX4P)P4R+A"3(
M`0``20'`3`'&38GH2`'Q3(GN2<'H&TC!Y@5,"<9$C00.3(GF2<'L`DR)\4C!
MYAY,">9!B?1("?),(>%,(>I("<I(BXPDT`$``$@!P4D!RTR)P4@#A"38`0``
M3`':38G#2,'A!4P!\$G!ZQM,"=F)R4@!RDR)Z4G![0)(P>$>08G33`GI38GE
M08G/2`G.32']3"'&3`GN38G=2`'P3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!
MZ`)(P>8>08G%20GPOM;!8LI,,<$QRDB+C"3@`0``2`'Q20',3(GI3`'B38GL
M2,'A!4G![!M,">&)R4@!RDR)V4C!X1Y)P>L"08G420G+3(G!38GF18G`3#'9
M2<'N&S'(2(N,).@!``!(`?%)`<]*C0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G!
M[0),B=E(P>`>18GW18G;20G%2(N$)/`!``!,,>E(`?`QRDR)^4P!P$C!Z1M(
M`<),B?A(P>`%2`G(2(N,)/@!``")P$@!PDR)X$@!\4G![`)(P>`>3`'938GK
M08G03`G@38G$18GM23'#2<'L&T4QWDZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)
MP>\"2,'A'D6)W$D)STB+C"0``@``2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB
M3(GA2,'I&TC!X@5("<I,B<%)P>@"B=)(P>$>20'52(N4)`@"``!,"<%-B?A)
M,<A%B>Y%B?](`?)%,<-(`=!,B?).C0083(GP2,'J&TC!X`5("=!(B<J)R8G`
M20'`3(G@2<'L`DC!X!Y%B<-)"<1(BX0D$`(``$PQXD@!\$$QU4R)VDP!^$D!
MQ4R)V$C!X`5(P>H;2`G03(GR2<'N`HG`2,'B'DD!Q4B+A"08`@``3`GR18GO
M2`'P2`'(3(GA18GD2#'103'(3(GY20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)
MV$G!ZP)(P>`>18G&20G#2(N$)"`"``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%
M,>5.C20H3(GP2,'@!4@)R$B+C"0H`@``B<!)`<1,B?A(`?%)P>\"2,'@'D@!
MRDR)V46)Y4P)^$6)VT@QP4$QR$R)Z4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,
MB?))P>X"2,'B'D6)QTD)UDB+E"0P`@``3(GY2,'I&T@!\DP!VDF)PXG`33'S
M13'<3HT<(DR)^DC!X@5("<I,B>E)P>T"B=)(P>$>20'32(N4)#@"``!,">E%
MB=Q(`?)(`=!,B?)%B?9(,<I!,=!,B>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)
MB<!)`<!,B?A)P>\"2,'@'D6)Q4D)QTB+A"1``@``2`'P3#'Z3`'P03'33(GJ
M20'#3(GH2,'J&TC!X`5("=!,B>))P>P"B<!(P>(>20'#2(N$)$@"``!,">)%
MB=Y)B=1(`?!(`<A,B?E%B?](,=&)TD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)
MP(G`2`'!3(GH2<'M`DC!X!Y!B<A)"<5(BX0D4`(``$TQ[$@!\$4QXTV)Q$P!
M^$G![!M)`<-,B<!(P>`%3`G@B<!)`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"18
M`@``20'V20'63(GJ18GM2#'",=%)C10.3(GA38GF2<'N&TC!X05,"?&)R4@!
MRDR)P4G!Z`)(P>$>08G620G(2(N,)&`"``!(`?%,`>E)B<6)P$TQQ44QZTV)
M]4D!RTR)\4G![1M(P>$%3`GIB<E)`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"1H
M`@``2`'Q2`'(3(G!18G`3#'A,<I(C0P03(GH3(GJ2,'J&TC!X`5("=!,B?))
MP>X"2,'B'HG`20G62(N4)'`"``!(`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!
MVDF)PTG!X`5)P>L;30G828G#2,'H`DG!XQY!`=!,B>I)P>T"20G#2(N$)'@"
M``!(P>(>20G51(GB00';2`'P1`'M3(E?$$@!PDR)\$B);QA,,>@QP4B-!`I,
MB<),B<%%`<A(P>(%2,'I&TR)1PA("<H!T$$!PD0#=R!,B1=,B7<@2(N$)(@"
M``!D2#,$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^CZY?__9BX/'X0`````
M`$%7059!54%455-(@^P(2(7_#X2Q````3(L]0H4``$V%_P^$H0````^V!X3`
M=`0\/75>13'D28L?2(7;=#E)B?5)B?Y-8^1,B?T/'X``````3(GB3(GV2(G?
MZ)+C__^%P'4'0H`\(SUT1TB#Q0A(BUT`2(7;==I(@\0(2(G86UU!7$%=05Y!
M7\,/'X0``````$F)_$F#Q`%!#[8$)(3`=`0\/77O02G\ZXP/'X``````3"G]
M2HU<(P%(P?T#08EM`.NT9@\?1```,=OKJ@\?0`!32(G[2(/L$&1(BP0E*```
M`$B)1"0(,<`/'X0``````#'`2(UT)`1(B=_H`?___TB%P'0T2&-4)`1(BP50
MA```2(T$T$B+4`A(B1!(A=)TT$B#P`A(BU`(2(D02(72=?#KOF8/'T0``$B+
M1"0(9$@S!"4H````=09(@\006\/HG>3__V9F+@\?A```````9I!!5T%6055!
M5%5(B?532(G[2(/L*&1(BP0E*````$B)1"08,<`QP(`^/0^4P$@!Q4B)[^@I
MX___2(UT)!1(B=])B<0QP.A7_O__2(7`#X0.`0``2(G'28G%Z`/C__],.>`/
M@]H```!,8W0D%$G!Y@,/M@.$P`^$K@$``#P]#X2F`0``2(G8#Q\`2(/``0^V
M$(32=`6`^CUU\$@IV$B82HU\(`),`S57@P``Z/+A__])B09(A<`/A((!``!(
MBP4_@P``2&-4)!1(C4L!2(L4T`^V`X@"/#UT'X3`=0GK&0\?`#P]=!)(@\$!
M#[9!_TB#P@&(`H3`=>K&`CTQP`\?1```#[9,!0"(3`(!2(/``83)=>\QP$B+
M7"089$@S'"4H````#X4?`0``2(/$*%M=05Q!74%>05_#9BX/'X0``````#'`
M9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[4/'T``3(L]F8(``$F#/P`/A+X`
M``!,B?@QTNL+#Q^$``````!$B>I(@\`(1(UJ`4B#.`!U[XUR`TAC]DC!Y@.+
M!9^2``"%P'5;QP61D@```0```$B)]^CIX/__2(7`#X1\````36/%3(G^2(G'
M3HTTQ0````!,B40D"$R)\NA"XO__3(M$)`A(B046@@``2(G!2L=$P0@`````
M1(EL)!3I;_[__TR)_^@XX___2(G!2(D%[H$``$B%P'0E36/%3HTTQ0````#K
MR0\?0``QP.EN_O__OA````!%,>WI7____[C_____Z<W^___H1>+__P\?1```
M055!5%532('LJ````&1(BP0E*````$B)A"28````,<!(A?]T"(`_`$B)_74K
M2(N$))@```!D2#,$)2@````/A1,!``!(@<2H````6UU!7$%=PV8/'T0``.C#
MX/__28G$2(7`=,A,B>?HP^+__TB%P`^$P@```$B-6!._!6!``+D"````2(G>
M\Z8/E\`<`(3`=-._!&!``+D#````2(G>\Z8/E\`<`(3`=+M(B>_H7N#__TB)
MWTF)Q>A3X/__08U\!0)(8__HAM___TF)V4F)Z+D'8$``28G%2(G'O@$````Q
MP$C'PO_____HXN'__[\!````2(GB3(GNZ)+A__],B>^#^/]T$(M$)!@E`/``
M`#T`0```=#KH==___TR)[^C=W___3(GGZ`7B__](A<`/A4+___\/'T``3(GG
MZ(#A__](B>_H6-___^G@_O__#Q\`Z*O^___KQ.CDX/__#Q]``%-(B?Y(B?N_
M`0```$B![*````!D2(L$)2@```!(B80DF````#'`2(GBZ&+@__^%P'4VBU0D
M&('B`/```('Z`$```'0(@?H`H```=1Z^`@```$B)W^@GX?__A<`/E,`/ML#K
M!P\?1```,<!(BXPDF````&1(,PPE*````'4)2('$H````%O#Z%7@__\/'T0`
M`$%5NO\/``!)B?5!5%5(B?V_#6!``%-(@>P8$```9$B+!"4H````2(F$)`@0
M```QP$B)YNB(W___A<!^=(U0_T2+)5I_``!(8]J`/!P`=5F%TG1D2(G:OB\`
M``!(B>?HC=W__TB%P'1/1(GGZ"#=__](B=E(B>)(B>Y(B<?H+]___TB+A"0(
M$```9$@S!"4H````=3M(@<08$```6UU!7$%=PV8/'T0``$ACV.NF#Q\`1(LE
MZ7X``$2)Y^C1W/__3(GJ2(GN2(G'Z//=___KLNA\W___9F8N#Q^$``````"0
M2(/L"(L]MGX``.BAW/__N0AB0`"Z\"%``+X<8$``2(G'2(/$".D&X/__9@\?
M1```2(/L"(L]AGX``.AQW/__2(G'Z+G___^+/7-^``#H7MS__T&XL6%``$4Q
MR;H`5D``3(G!OCA@0`!(B<=(@\0(Z1S>__]F9BX/'X0``````)!32('L("``
M`&1(BP0E*````$B)A"08(```,<#H8-W__[E-8$``0;D88$``2(GG08G`N@$0
M``"^`0```#'`Z#[?__^Z`!```$B-M"00$```2(GGZ`G>__\QR87`>#.->`%(
MB<-(8__HE=S__TB)P4B%P'0=2&/;2(VT)!`0``!(B<=(B=KH1]___\8$&`!(
MB<%(BY0D&"```&1(,Q0E*````$B)R'4)2('$("```%O#Z#S>__]F9BX/'X0`
M`````)#I.____V9F+@\?A```````059!54F)]4%454B)_;]98$``4TB![+`0
M``!D2(L$)2@```!(B80DJ!```#'`2(UT)`SH^??__[XO````2(GO2(G#Z'G=
M__](A<!T/$B)[K]B8$``,<#H-?G__TB)Z$B+C"2H$```9$@S#"4H````#X6%
M`0``2('$L!```%M=05Q!74%>PP\?`$B)[^A@W/__OF]@0`!,B>]!B<3HH-W_
M_TF)QDB%P'2D08/$`4&`/@!!O05@0``/A-$````/'T``2(7;=!-,B?9(B=_H
M8-W__X7`#X23````3(GWZ!#<__^)PDB808!\!O\O=1</'T``@^H!2&/"08!\
M!O\O0<8$!@!T[40!XH'Z_P\```^/.O___TB#[`BY9V%``$V)\#'`54&Y<6!`
M`+H`$```O@$```!(C;PDL````.ARW?__2(U4)""_`0```$B-M"2P````Z!O=
M__]:687`=1"+1"0H)0#P```]`(```'15OF]@0``Q_^C)W/__28G&2(7`#X3)
M_O__08`^``^%,____TB%VW0>N0(```!(B=Y,B>_SI@^7P!P`A,!TPP\?A```
M````0;X%8$``N@$```#I0____[X!````2(V\)*````#H[MS__X7`=95(C;0D
MH````+]B8$``Z*CW__](C;PDH````.@+W/__Z63^___H(=S__Y`/MA=(B?B$
MTG0>9@\?1```2(/'`8#Z+P^V%T@/1,>$TG7NPP\?1```PP\?@`````!(A?\/
MA)\```"`/P`/A)8```!32(G[Z*7:__](C50#_T@YTW(4ZR=F#Q^$``````!(
M@^H!2#G3=!J`.B]T\NL%@#HO="A(@^H!2#G3<O)(.=-U&H`Z+W1@OW%@0`!;
MZ6W;__\/'T0``(`Z+W4)2(/J`4@YTW+R2"G:,<!(C4H"2('Y`!```'<;2(/"
M`;D`$```2(G>OZ#"0`#HPMC__[B@PD``6\,/'P"_!6!``.D>V___9@\?1```
MOP5@0`!;Z0W;__]F9BX/'X0``````&:02(/L2/,/;P4$&@``OW-@0`#S#V\-
M!QH``&1(BP0E*````$B)1"0X,<`/MP4`&@``#RE$)!!FB40D,#'`#RE,)"#H
MNO7__S'`OWQ@0`#HKO7__S'`OX1@0`#HHO7__S'`OXU@0`#HEO7__S'`OY1@
M0`#HBO7__S'`OZ1@0`#H?O7__S'`OUE@0`#H<O7__S'`O[!@0`#H9O7__S'`
MO[I@0`#H6O7__S'`O\1@0`#H3O7__S'`OV)@0`#H0O7__S'`2(UT)`R_SF!`
M`.AA]/__2(7`=`](B<:_NF!``#'`Z*WU__\QP$B-="0,O]]@0`#H//3__TB%
MP'0/2(G&O_%@0``QP.B(]?__,<!(C70D#+_\8$``Z!?T__](A<!T.DB)QK]9
M8$``,<#H8_7__S'`OBAA0`"_E&!``.A2]?__2(M$)#AD2#,$)2@```!U7TB#
MQ$C##Q]$```QP$B-="0,OPQA0`#HQ_/__TB%P'022(G&O[!@0``QP.@3]?__
MZZZ02(UT)"&_'6%``+D*````\Z8/E\`<`(3`=9-(C70D*[^P8$``,<#HY?3_
M_^N`Z&[9__]F9BX/'X0```````\?`$B#[!AD2(L$)2@```!(B40D"#'`BP5N
M>```@_C_=!E(BW0D"&1(,S0E*````'4^2(/$&,,/'T``2(UT)`2_L&!``#'`
MZ"?S__](B<(QP$B%TG02#[82@/HP#Y7!,<"$T@^5P"'(B04=>```Z[+H[MC_
M_V9F+@\?A```````#Q\`2(/L".@'V?__B<?H<-?__TB%P'0+2(L`2(/$",,/
M'P`QP$B#Q`C#9@\?A```````05152(G]ORIA0`!32(/L$&1(BP0E*````$B)
M1"0(,<!(C70D!.B6\O__2(GN2(7`=`B`.`!(B<-U)K\J84``,<#HVO/__TB+
M1"0(9$@S!"4H````=79(@\006UU!7,.02(G'Z)C7__](A<!UV4B)[^@+U___
M2(G?28G$Z`#7__])C7P$`N@VUO__2(/L"$F)Z+EG84``4TC'PO____](B<=)
MB<1!N6]@0`"^`0```#'`Z(K8__],B>:_*F%``#'`Z%OS__]86NEZ____Z-_7
M__]F9BX/'X0```````\?0`!!5T%6055!5$F)_+]98$``55-(@>R(@0``9$B+
M!"4H````2(F$)'B!```QP$B-="0<2,=$)"!&84``2,=$)"@%8$``2,=$)#``
M````2,=$)&#Q8$``2,=$)&CJ8$``2,=$)'!+84``2,=$)'@'84``2,>$)(``
M``!384``2,>$)(@`````````2,=$)$`Z84``2,=$)$A784``2,=$)%``````
MZ#CQ__](A<!T"8`X``^%H@0``#'`Z#/^__](B<-(A<`/A!<$``!(B=_HS]7_
M_TB-?``!Z`75__^`.P!)B<5T-4R)[4G'QO____\/'P!$#[8#2(GO,<"Y8&%`
M`$R)\KX!````2(/#`4B#Q0+H3=?__X`[`'782(U<)&B_\6!``.L5#Q]``$B#
MPPA(BWOX2(7_#X2/`0``2(UT)!PQP.B;\/__2(G%2(7`=-N`.`!TUDB)Q^B6
M]?__A<!TRDB)[^A*UO__2(G#2(7`#X16`0``9@\?1```2(G9BQ%(@\$$C8+_
M_O[^]](AT"6`@("`=.F)PL'J$*F`@```#T3"2(U1`D@/1,J)P@#"3(GJ2(/9
M`T@IV8LR2(/"!(V&__[^_O?6(?`E@("`@'3IB<;![A"I@(````]$QDB-<@)(
M#T36B<9``,9(@]H#3"GJ1(VT$00$``!-8_9,B??HX-/__T%50;EQ8$``28G8
M:&YA0`!(B<=(B<6Y96%``$C'PO____^^`0```#'`Z#+6__^^P`$``$B)[^B5
MUO__05A!68/X_W42Z%?5__]$BPA!@_D1#X75`@``2(V4))````!(B>Z_`0``
M`.@5U?__08G%A<`/A*H```!)BPPD2(L]WW0``$F)Z#'`NEAB0`"^`0```#';
MZ.G2__](BXPD>($``&1(,PPE*````$B)V`^%*@@``$B!Q(B!``!;74%<05U!
M7D%?PP\?1```,>UF#Q]$``!(8\5(BUS$($B%VW0[@#L`=#9(B=^#Q0'H`_3_
M_X7`=-](B=_HM]3__TB)PTB%P`^%<_[__TACQ4B+7,0@2(7;=<MF#Q]$```Q
MV^E9_O__D(N$)*@````E`/```#T`0```#X4_____BYPDK````.B]U/__.<,/
MA2O___^+A"2H````)?\!```]P`$```^%%/___TR)]^AVTO__2(UT)!R_-6%`
M`$B)PS'`Z&+N__](A<`/A`D"``!(B<?H(=3__TF+/"1(B<;H%?;__TF)QDB%
MP`^$Z0$``$R)]^CQTO__@_@#?CQ(8]"_<V%``+D%````28UT%OSSI@^7PH#:
M`(32=1Z#^`0/A*H%``"#Z`1(F$&`?`;_+P^$F04```\?0``QP.AY^O__A<!U
M%3'V3(GWZ`O3__]!B<>%P`^%B0$``+XH84``O[!@0``QP$G'Q/_____H&.__
M_^@STO__:+%A0`!)B>A(B=]02,?"_____T&Y<6!``#'`N8QA0`"^`0```.@)
MU/__6%KK2`\?1```Z#O3__^#.!%U2^CQT?__08/%`4B#[`A)B>AHL6%``+F:
M84``3(GB2(G?055!N7%@0`"^`0```%`QP.C!T___2(/$(+[``0``2(G?Z"#4
M__^#^/]TJTB)[^C3T?__2(G>OUE@0``QP.AT[O__2(G?Z$SZ___IOOW__P\?
M@`````"_.F%``#'MZP\/'X``````2&/%2(M\Q$!(A?]T>TB-="0<,<"#Q0'H
MU.S__TB%P'3?@#@`=-I(B<?HDM+__TB)PTB%P'3*Z9[[__])BPPD2(L]*G(`
M`$F)Z#'`NAAB0`"^`0```#';Z#30___I1OW__P\?@`````!(B<=(B00DZ+SY
M__](BP0D2(G'Z$#2__](B</I'_W__[\-````NS]A0`#H6=#__TF)Q>E4^___
MD$V+-"3I#O[__[H"````2,?&[O___XG'Z)32__^Z!@```$B-M"1P`0``1(G_
MZ/_/__^`O"1P`0```'4.@+PD<0$``$,/A'D$```QTC'V1(G_Z%O2__^XB:O-
M[TC'A"20`````2-%9TB)A"28````2"V+SA)72(F$)*````!(!?($&"M(B80D
ML````$B-A"3(````2,>$)*@```!V5#(02,>$)+@`````````2,>$),``````
M````QX0D"`$```````!(B00D#Q\`N@"```!(C;0D<`$``$2)_^A3S___28G&
M08G%A<`/CF(!``!(B[0DN````$ECQDB+E"3`````C0S&2#GQ2(F,)+@```!(
M@](`2,'H'4@!T$B)A"3`````2&.$)`@!``"%P`^$$0$``$&]0````$B+#"1(
MC;0D<`$``$$IQ44Y[DB-/`%%#T[N36/E3(GBZ,;1__^+A"0(`0``1`'HB80D
M"`$``(/X0`^%5/___T2)\$B-O"20````1"GH08G%2(V$)'`!``!.C30@Z)K4
M__]!@_T_#XZ6`@``08/M0$2)Z,'H!D&)Q(E$)`Q)@\0!2<'D!DT!]`\?0`#S
M00]O#O-!#V]6$$B-O"20````28/&0/-!#V]>X/-!#V]F\`\1C"3(````#Q&4
M)-@````/$9PDZ`````\1I"3X````Z"C4__]-.>9ULT2+="0,0<'F!D4I]4B+
M/"1)8]6Y2````$R)YNB3SO__1(FL)`@!``#ICO[__V8/'T0``$R-M"1P`0``
MZ4G___]$B?_H:\W__TB+A"2X````1(ND)+@```!$BZPDP````$C!Z`-!#\R#
MX#]!#\V-4`%(F,:$!,@```"`@_HX#XZN`0``N$````!(8\HIT$B-M`S(````
MB<)T#S'`B<&#P`'&!`X`.=!R\TB-O"20````Z&[3__]F#^_`2,>$)/@`````
M````#Q&$),@````/$80DV`````\1A"3H````2(V\))````!$B:PD``$``$R-
MO"0A`0``2<?%_____T2)I"0$`0``3(VD)$`!``#H$M/__XN$))````!-C70D
M*$0/MH0DDP````_(B80D(`$``(N$))@````/R(F$)"0!``"+A"2@````#\B)
MA"0H`0``BX0DJ`````_(B80D+`$``(N$)+`````/R(F$)#`!``#I#P````\?
M@`````!%#[8'28/'`4R)YT4/ML"Y8&%``$R)ZKX!````,<!)@\0"Z"'/__]-
M.>9UU,:$)&@!````:+%A0`!(C80D2`$``%"Y?6%``+X!````28GH0;EQ8$``
M2,?"_____TB)WS'`Z.+.__]97NDP^___38MD)`A-A>0/A%WZ__],B>?H!<W_
M_TB#^`,/ADOZ__])C70$_+]X84``N04```#SI@^7P!P`A,!-#T3TZ2KZ__]-
MB?3IV_W__[@X````,?\IT$ACTDB-E!3(````@_@(<RFH!`^%V0```(7`#X2#
M_O__Q@(`J`(/A'C^__\Q_V:)?`+^Z6S^__]FD(G!2,<"`````$C'1`KX````
M`$B-2@A(@^'X2"G*`="#X/B#^`@/@C_^__^#X/@QTHG6@\((2(D\,3G"<O/I
M*/[__X"\)'(!``!!#X5Y^___@+PD<P$``$,/A6O[__^`O"1T`0``2`^%7?O_
M_X"\)'4!``!%#X5/^___N@(```!(Q\;&____1(G_Z*+-__](C;0D<`$``+HI
M````1(G_Z`W+__]HL6%``$B-A"1X`0``Z93^__\/'P#'`@````#'1`+\````
M`.F?_?__Z/#,__]!5D%505154TB#[!"+/2YL``!D2(L$)2@```!(B40D"#'`
MZ`G*__^+/1-L``!(B</H^\G__TB-="0$OY1@0``/MI.X````B)"Y````,<#H
MK>;__TB%P'0)@#@Q#X3?`@``,<#H:/'__XL]TFL``.B]R?__N0L```"Z`0``
M`+ZK84``2(G'Z*;*__^++;!K``!(A<`/A,8```!(BT`0@ST,?````4R+:"@/
MCK$````QV^LQ9@\?1```28MV$$B+#>5[``!)8]1(BSS1Z#',__^+%=M[``"%
MP'5[@\,".=-$B>-]<8GO1(UC`>A"R?__,<E(8]-,B>Y(B<?H<LO__TB%P'1%
M3(LPBRTT:P``08M&#"4`!"``/0`$``!TG(GOZ`W)__],B?:Y`@```#'22(G'
MZ,O,__^++05K``!(B<;I>?___P\?1```BQ5B>P``BRWL:@``C4+_.=@/A'$!
M``")[^C*R/__N0,```"Z`0```+ZP84``2(G'Z+/)__](B<-(A<!T,TB+0!"+
M/;%J``!(BRCHF<C__[JR84``2(G'2(GNZ+G)__](BT,02(L8]D,.0`^%Q`$`
M`(L]@FH``.AMR/__N0,```"Z`0```+ZW84``2(G'Z%;)__](B<-(A<!T/4B-
M="0$OV)@0``QP.@-Y?__2(G%2(7`#X11`0``2(M#$(L]-VH``$B+&.@?R/__
M2(GJ2(G>2(G'Z$')__^+/1MJ``#H!LC__[H!````OKEA0`!(B<?H%,C__XL]
M_FD``$B)P^CFQ___2(G>NLYA0`!(B<?H!LG__XL]X&D``.C+Q___2(UT)`2_
M66!``,:`N0`````QP.B#Y/__2(G#2(D%,7H``$B%P`^$@````+[``0``2(G?
MZ%/+__^-4`&#^@%V"8/X$0^%[@```$B+1"0(9$@S!"4H````#X75````2(/$
M$%M=05Q!74%>PY"#^@$/CH;^__^[`0```&:0B>^#PP'H1L?__TR)[DB)Q^@K
MR/__.1VU>0``BRT_:0``?]WI5_[__P\?A```````2(L]D7D``.@$\O__2(G#
M2(D%DGD``$B%P`^%8?___[^P8D``,<#H]<G__P\?1```@'@!``^$'OW__^D2
M_?__D$B+!5%Y``"+/>-H``!(BRA(BT,02(L8Z,3&__](B>Y(B=_H*>G__^FC
M_O__BSV^:```Z*G&__](B=Y(B<?H3LG__^DA_O__Z%3)__^)P4B+!0-Y``!(
MB=J_V&)``$B+,#'`Z'G)__]F#Q^$``````!52(G]4TB#[`CH,NW__P^V$$B)
MPX32=!H/'X0``````$B#P`&`^B\/MA!(#T38A-)U[C'`Z)?O__](A>UT(H7`
M=!Z`?0``=!B_;F%``+D$````2(G>\Z8/E\`<`(3`=`=(@\0(6UW#2(/$"$B)
M[UM=Z7OF__]F+@\?A```````D$%728G7059)B?9!54&)_4%43(TE.&,``%5(
MC2TX8P``4TPIY4B#[`CHD\7__TC!_0-T&S';#Q\`3(GZ3(GV1(GO0?\4W$B#
MPP%(.=UUZDB#Q`A;74%<05U!7D%?PP\?`,-F+@\?A```````#Q]$``!(BPU9
M9P``Z13&__](@^P(2(/$",,`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P
M,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E
M<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2
M.CI086-K97(Z.E9%4E-)3TX`,2XP-#<`+64`+2T`````````7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("```````````'!E<FQX<VDN8P``````
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``````````!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I
M;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@
M)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<[
M"F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP
M+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/
M3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"![
M"E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T
M7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO
M9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY
M("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F
M9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD
M;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE
M(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*
M9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S
M("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!
M4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I
M>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL
M87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E
M96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@
M7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&
M2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R
M97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE
M("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B
M+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*
M96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C
M(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D
M8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T
M*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA
M<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D
M:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H
M("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F
M:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA
M;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H
M+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE
M.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@
M0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ
M1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I
M<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N
M86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\[
M"GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@
M=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L
M92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?
M4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P
M<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@
M)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]4
M14U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@
M0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`
M05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG
M+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO
M9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A
M9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II
M<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A
M;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L
M("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D
M<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P
M,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT
M.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA
M9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T
M(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[
M)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D
M,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R
M*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL
M97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@
M=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI
M8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE
M<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2![
M"B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;
M7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T
M.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII
M9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M
M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D
M,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD
M(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L
M"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I
M*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)
M3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2([
M"F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S
M*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F
M:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E
M;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*
M?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@
M>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H
M*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H
M("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^
M=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP
M;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@
M;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@
M(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M
M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H
M,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS
M=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL
M93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U
M:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL
M97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B
M(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,
M;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I
M<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD
M;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D
M<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P
M96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R
M.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T
M,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE
M*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X
M(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T
M>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E
M('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7([
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q
M(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D
M;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92([
M"G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L
M;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE
M(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R
M:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O
M9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?
M97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA
M;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]
M("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD
M969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P
M=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1
M)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A
M97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.
M5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<
M4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L
M;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B
M0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E
M(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*,3L*7U]%3D1?7PH```````$;`SOD````&P```,B`__\P`0``N(3_
M_\0%``"HAO__``$``(B'__]8`0``J)W__Z@!``!XGO__]`$```B?__\8`@``
M6*'__V0"``"XHO__H`(``$BC___$`@``**3__P`#``!8I/__&`,``*BD__\P
M`P``:*7__U0#``!XI?__:`,``'BG___``P``J*?__]0#``!XJ/__``0``#BJ
M__\<!```N*K__S@$``#HJO__6`0``,BK__^8!```J+;__TP%``!HNO__D`4`
M`.BZ___H!0``2+O__S`&``!8N___2`8````````4``````````%Z4@`!>!`!
M&PP'")`!!Q`4````'````*"%__\K```````````````4``````````%Z4@`!
M>!`!&PP'")`!```D````'````)!____P`P````X01@X82@\+=PB``#\:.RHS
M)"(`````3````$0````HAO__%A8```!"#A"/`D8.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P='#M`%`_$5"@XX00XP00XH0@X@0@X80@X00@X(00L```!(````
ME````/B;___,`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.
M0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L`(````.````!\G/__@P````!!
M#A"#`D<.(`)T"@X000X(00L`2`````0!``#HG/__2P(```!"#A"/`D(.&(X#
M0@X@C01"#BB,!4$.,(8&1`XX@P='#F`#%P$*#CA!#C!!#BA"#B!"#AA"#A!"
M#@A+"S@```!0`0``[)[__UP!````0@X0C0)"#AB,`T$.((8$00XH@P5'#M`!
M?@H.*$$.($$.&$(.$$(."$<+`"````",`0``$*#__XL`````00X0@P)2#K`!
M`G$*#A!!#@A!"S@```"P`0``?*#__]0`````0@X0C0)*#AB,`T$.((8$20XH
M@P5'#L`@`GX*#BA!#B!!#AA"#A!"#@A'"Q0```#L`0``(*'__RH`````1`X0
M80X(`!0````$`@``.*'__T0`````1`X0>PX(`"`````<`@``<*'__[0`````
M00X0@P)'#K!``J4*#A!!#@A!"Q````!``@``#*+__P4`````````5````%0"
M```(HO___P$```!"#A".`D(.&(T#10X@C`1!#BB&!4D.,(,&1P[@(0)B"@XP
M00XH00X@0@X80@X00@X(1`L"C@[H(4L.\"%U#N@A00[@(0```!````"L`@``
ML*/__RD`````````*````,`"``#,H___PP````!3#A"#`@)+"L,."$H+?`X(
M1,-0#A"#`D;##@@8````[`(``'"D__^R`0```$0.4`-.`0H."$8+&`````@#
M```4IO__<@````!$#B!O"@X(10L``!P````D`P``>*;__R<`````1`X06`H.
M"$0+1@X(````/````$0#``"(IO__T0````!"#A",`D$.&(8#20X@@P1$#C`"
M2@H.($$.&$$.$$(."$(+;@XX20Y`;PXX00XP`+````"$`P``**?__^`*````
M0@X0CP)"#AB.`T(.((T$0@XHC`5)#C"&!D$..(,'1P[`@P(#Z0$.R(,"3@[0
M@P)M#LB#`D(.P(,"`GD*#CA!#C!!#BA"#B!"#AA"#A!"#@A&"P-J`0[(@P)'
M#M"#`E\.R(,"00[`@P)>#LB#`D@.T(,"30[8@P),#N"#`DL.P(,"`ZX$#LB#
M`DD.T(,"90[(@P)!#L"#`@,X`0H.R(,"4`L``$`````X!```5+'__[<#````
M0@X0C@)"#AB-`T(.((P$00XHA@5!#C"#!D0.0`.Z`@H.,$$.*$$.($(.&$(.
M$$(."$(+,````'P$``#0M/__=0````!!#A"&`D0.&(,#1`X@`EL*#AA!#A!!
M#@A!"T0.&$0.$$$.""````"P!```['[__^P!````00X0@P)$#D`#DP$*#A!!
M#@A!"T0```#4!```^+3__UT`````0@X0CP)%#AB.`T4.((T$10XHC`5(#C"&
M!D@..(,'1PY`:@XX00XP00XH0@X@0@X80@X00@X(`!0````<!0``$+7__P$`
M`````````````!`````T!0``"+7__PP`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#0)D```````*`F0````````0`````````!````
M``````$`````````A@$````````!`````````-4!`````````0````````#D
M`0````````$`````````\`$````````!`````````/L!`````````0``````
M```%`@````````$`````````$P(````````!`````````"`"````````#```
M````````($````````T`````````O%I````````9`````````)"]0```````
M&P`````````(`````````!H`````````F+U````````<``````````@`````
M````]?[_;P`````(`T````````4`````````6`I````````&`````````&@#
M0```````"@````````"W`P````````L`````````&``````````5````````
M`````````````P``````````P$````````(`````````T`4````````4````
M``````<`````````%P````````"X#T````````<`````````*`]````````(
M`````````)``````````"0`````````8`````````/[__V\`````J`Y`````
M``#___]O``````(`````````\/__;P`````0#D``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@O4`````````````````````````````V($```````$8@
M0```````5B!```````!F($```````'8@0```````AB!```````"6($``````
M`*8@0```````MB!```````#&($```````-8@0```````YB!```````#V($``
M``````8A0```````%B%````````F(4```````#8A0```````1B%```````!6
M(4```````&8A0```````=B%```````"&(4```````)8A0```````IB%`````
M``"V(4```````,8A0```````UB%```````#F(4```````/8A0```````!B)`
M```````6(D```````"8B0```````-B)```````!&(D```````%8B0```````
M9B)```````!V(D```````(8B0```````EB)```````"F(D```````+8B0```
M````QB)```````#6(D```````.8B0```````]B)````````&(T```````!8C
M0```````)B-````````V(T```````$8C0```````5B-```````!F(T``````
M`'8C0```````AB-```````"6(T```````*8C0```````MB-```````#&(T``
M`````-8C0```````YB-```````#V(T````````8D0```````````````````
M`````````/____\`````(&-```````!'0T,Z("AB;&%C:U!A;G1H97(@."XR
M+C$M,"XR,#$X,#@R-"XQ8E`I(#@N,BXQ(#(P,3@P.#(T```N<VAS=')T86(`
M+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I
M;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR
M;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I
M;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M``````````````````````````````````````````L````!`````@``````
M``"H`D```````*@"````````'`````````````````````$`````````````
M```````3````!P````(`````````Q`)```````#$`@```````"``````````
M```````````$````````````````````(0````<````"`````````.0"0```
M````Y`(````````D````````````````````!````````````````````#0`
M``#V__]O`@`````````(`T````````@#````````7``````````%````````
M``@````````````````````^````"P````(`````````:`-```````!H`P``
M`````/`&````````!@````$````(`````````!@`````````1@````,````"
M`````````%@*0```````6`H```````"W`P```````````````````0``````
M`````````````$X```#___]O`@`````````0#D```````!`.````````E```
M```````%``````````(``````````@````````!;````_O__;P(`````````
MJ`Y```````"H#@```````(``````````!@````(````(````````````````
M````:@````0````"`````````"@/0```````*`\```````"0``````````4`
M````````"``````````8`````````'0````$````0@````````"X#T``````
M`+@/````````T`4````````%````%@````@`````````&`````````!^````
M`0````8``````````"!`````````(````````!<````````````````````$
M````````````````````>0````$````&`````````"`@0```````("``````
M``#P`P``````````````````$``````````0`````````(0````!````!@``
M```````0)$```````!`D````````K#8``````````````````!``````````
M``````````"*`````0````8`````````O%I```````"\6@````````D`````
M```````````````$````````````````````D`````$````"``````````!@
M0````````&````````!8/P``````````````````"```````````````````
M`)@````!`````@````````!8GT```````%B?````````Y```````````````
M``````0```````````````````"F`````0````(`````````0*!```````!`
MH````````'@%```````````````````(````````````````````L`````X`
M```#`````````)"]0```````D*T````````(````````````````````"```
M```````(`````````+P````/`````P````````"8O4```````)BM````````
M"`````````````````````@`````````"`````````#(````!@````,`````
M````H+U```````"@K0```````%`"````````!@`````````(`````````!``
M````````T0````$````#`````````/"_0```````\*\````````0````````
M````````````"``````````(`````````-8````!`````P``````````P$``
M``````"P````````"`(```````````````````@`````````"`````````#?
M`````0````,`````````",)````````(L@```````"``````````````````
M```(````````````````````Y0````@````#`````````$#"0```````*+(`
M``````"($```````````````````(````````````````````.H````!````
M,````````````````````"BR````````.`````````````````````$`````
M`````0`````````!`````P````````````````````````!@L@```````/,`
>```````````````````!````````````````````
